package gui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.UIManager;

/**
 * This code is provided for use in the course SWE-622, Distributed Software
 * Systems. Feel free to use and change this code, but the author is not liable
 * for any such use or misuse.
 * 
 * This class provides the interface IOperationsConsole and requires none.
 * Create an instance of this class to show a window for an exchange console.
 * 
 * @see WindowClosingListener
 * 
 * @author jpsousa
 * @date Sep 21, 2006
 */
public class JFrameExchangeGUI extends JFrame implements IOperationsConsole {
	private static final long serialVersionUID = 1L;

	JScrollOperationsTable _operationsTable;

	public JFrameExchangeGUI(String exchange) {
		super(exchange + " Exchange");
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			e.printStackTrace();
		}
		setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
		addWindowListener(new WindowClosingListener(this));

		_operationsTable = new JScrollOperationsTable();
		JPanelOperationsTable panel = new JPanelOperationsTable(
				_operationsTable);
		setContentPane(panel);
		pack();
		setVisible(true);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see gui.IOperationsConsole#logOperation(java.lang.String,
	 *      java.lang.String, java.lang.String, java.lang.String,
	 *      java.lang.String)
	 */
	public void logOperation(String exchange, String op, String product,
			String qt, String price, boolean stale) {
		_operationsTable.logOperation(exchange, op, product, qt, price, stale);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see gui.IOperationsConsole#clearLog()
	 */
	public void clearLog() {
		_operationsTable.clearLog();
	}


	/**
	 * @author jpsousa
	 * @date Sep 21, 2006
	 */
	private class JPanelOperationsTable extends JPanel {
		private static final long serialVersionUID = 1L;

		JPanelOperationsTable(JScrollOperationsTable opsTable) {
			setLayout(new GridBagLayout());
			GridBagConstraints gbConstraints = new GridBagConstraints();
			gbConstraints.weightx = 1;
			gbConstraints.weighty = 1;
			gbConstraints.insets = new Insets(5, 5, 5, 5);
			gbConstraints.fill = GridBagConstraints.BOTH;
			add(opsTable, gbConstraints);
		}
	}
}
